@@ -1,36 +1,24 @@
-from typing import List
-from enum import Enum
-import datetime
-from typing import Optional
-
 from event_stream.models.model import *
-from pydantic import BaseModel
-import databases
-import sqlalchemy
-from fastapi import FastAPI, status
-from fastapi.middleware.cors import CORSMiddleware
-from pydantic import BaseModel
 from sqlalchemy import Table, Column, MetaData, create_engine
-from enum import Enum
 import os
 import urllib
-import event_stream.models
 from sqlalchemy.orm import sessionmaker
 
 
 class DAO(object):
 
     def __init__(self):
-        host_server = os.environ.get('POSTGRES_HOST', 'localhost')
+        host_server = os.environ.get('POSTGRES_HOST', 'postgres')
         db_server_port = urllib.parse.quote_plus(str(os.environ.get('POSTGRES_PORT', '5432')))
-        database_name = os.environ.get('POSTGRES_DB', 'fastapi')
-        db_username = urllib.parse.quote_plus(str(os.environ.get('POSTGRES_USER', 'postgres')))
-        db_password = urllib.parse.quote_plus(str(os.environ.get('POSTGRES_PASSWORD', 'secret')))
+        database_name = os.environ.get('POSTGRES_DB', 'amba')
+        db_username = urllib.parse.quote_plus(str(os.environ.get('POSTGRES_USER', 'streams')))
+        db_password = urllib.parse.quote_plus(str(os.environ.get('POSTGRES_PASSWORD', 'REPLACE_ME')))
+
         # ssl_mode = urllib.parse.quote_plus(str(os.environ.get('ssl_mode','prefer')))
         DATABASE_URL = 'postgresql://{}:{}@{}:{}/{}'.format(db_username, db_password, host_server,
                                                             db_server_port, database_name)
-
-        engine = create_engine(DATABASE_URL)
+        print(DATABASE_URL)
+        engine = create_engine('postgresql+psycopg2://streams:REPLACE_ME@postgres:5432/amba')
         Base.metadata.create_all(engine)
         # database = databases.Database(DATABASE_URL)
 
@@ -44,39 +32,46 @@ class DAO(object):
         return obj
 
     def get_object(self, table, key):
-        return self.session.query(table).get(key)
+        return self.session.query(table).filter(key).first()
 
-    def save_if_not_exist(self, obj, table, key):
-        obj_db = self.get_object(table, key)
+    def save_if_not_exist(self, obj, table, **kwargs):
+        obj_db = self.get_object(table, kwargs)
         if not obj_db:
             return self.save_object(obj)
         else:
             return obj_db
 
     def save_publication(self, publication_data):
-        publication = Publication(**publication_data)
-        publication = self.save_object(publication)
+        publication = Publication(doi=publication_data['doi'], type=publication_data['type'],
+                                          pubDate=publication_data['pubDate'], year=publication_data['year'],
+                                          publisher=publication_data['publisher'],
+                                          citationCount=publication_data['citationCount'],
+                                          title=publication_data['title'],
+                                          normalizedTitle=publication_data['normalizedTitle'],
+                                          abstract=publication_data['abstract'])
+        publication = self.save_if_not_exist(publication, Publication, doi=publication.doi)
 
         authors = publication_data['authors']
         for author_data in authors:
-            author = Author(**author_data)
-            author = self.save_if_not_exist(author, Author, {'normalizedName': author.normalized_name})
+            author = Author(name=author_data['name'],  normalizedName=author_data['normalizedName'])
+
+            author = self.save_if_not_exist(author, Author, normalizedName=author.normalizedName)
 
             publication_authors = PublicationAuthor({'authorId': author.id, 'publicationId': publication.id})
             self.save_object(publication_authors)
 
         sources = publication_data['source_id']
         for sources_data in sources:
-            source = Source(**sources_data)
-            source = self.save_if_not_exist(source, Source, {'title': source.title})
+            source = Source(title=sources_data['title'],  url=sources_data['url'])
+            source = self.save_if_not_exist(source, Source, title=source.title)
             publication_sources = PublicationSource({'sourceId': source.id, 'publicationId': publication.id})
             self.save_object(publication_sources)
 
         fields_of_study = publication_data['fieldOfStudy']
         for fos_data in fields_of_study:
-            fos = FieldOfStudy(**fos_data)
+            fos = FieldOfStudy(name=fos_data['name'],  normalizedName=fos_data['normalizedName'])
             fos.level = 2
-            fos = self.save_if_not_exist(fos, FieldOfStudy, {'normalizedName': fos.normalized_name})
+            fos = self.save_if_not_exist(fos, FieldOfStudy, normalizedName=fos.normalizedName)
             publication_fos = PublicationFieldOfStudy({'fieldOfStudyId': fos.id, 'publicationId': publication.id})
             self.save_object(publication_fos)
 
